@@ -28,7 +28,16 @@ _TESTED_DB_VERSIONS = ["6000", "5001", "4025", "4016", "3301", "2622"]
 # Photos 7 (12.0.1) == 15323
 # Photos 8 (13.0.0) == 16320
 # Photos 9 (14.0.0 dev preview) = 17120
-_TEST_MODEL_VERSIONS = ["13537", "13703", "14104", "15323", "16320", "17120", "18402", "18508"]
+_TEST_MODEL_VERSIONS = [
+    "13537",
+    "13703",
+    "14104",
+    "15323",
+    "16320",
+    "17120",
+    "18402",
+    "18508",
+]
 
 _IPHOTO_VERSION = "0000"
 
@@ -50,6 +59,8 @@ _PHOTOS_9_MODEL_VERSION = [17000, 17599]  # Sonoma dev preview: 17120
 _PHOTOS_9_14_6_MODEL_VERSION = [17600, 17999]  # macOS 14.6 changed the schema
 _PHOTOS_10B1_MODEL_VERSION = [18000, 18200]  # Sequoia dev preview 1: 18164
 _PHOTOS_10_MODEL_VERSION = [18201, 18999]
+_PHOTOS_11_MODEL_VERSION = [19063, 19319]
+_PHOTOS_11_1_MODEL_VERSION = [19320, 19999]  # macOS 26.1
 
 # the preview versions of 12.0.0 had a difference schema for syndication info so need to check model version before processing
 _PHOTOS_SYNDICATION_MODEL_VERSION = 15323  # 12.0.1
@@ -187,6 +198,38 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
         "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
     },
+    11: {  # macOS 16 / 26 Tahoe
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_51KEYWORDS",
+        "ALBUM_JOIN": "Z_32ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_32ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_32ASSETS.Z_32ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_32ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
+        "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
+    },
+    11.1: {  # macOS 16 / 26.1 Tahoe
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_52KEYWORDS",
+        "ALBUM_JOIN": "Z_33ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_33ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_33ASSETS.Z_33ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_33ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
+        "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
+    },
 }
 
 # Which version operating systems have been tested
@@ -241,6 +284,12 @@ _TESTED_OS_VERSIONS = [
     ("15", "2"),
     ("15", "3"),
     ("15", "4"),
+    ("15", "5"),
+    ("15", "6"),
+    ("15", "7"),
+    ("26", None),
+    ("26", "0"),
+    ("26", "1"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
